@@ -1,10 +1,10 @@
 #' Construct NWIS url for data retrieval
 #'
-#' Imports data from NWIS web service. This function gets the data from here: \url{http://nwis.waterdata.usgs.gov/nwis/qwdata}
-#' A list of parameter codes can be found here: \url{http://nwis.waterdata.usgs.gov/nwis/pmcodes/}
-#' A list of statistic codes can be found here: \url{http://nwis.waterdata.usgs.gov/nwis/help/?read_file=stat&format=table}
+#' Imports data from NWIS web service. This function gets the data from here: \url{https://nwis.waterdata.usgs.gov/nwis/qwdata}
+#' A list of parameter codes can be found here: \url{https://nwis.waterdata.usgs.gov/nwis/pmcodes/}
+#' A list of statistic codes can be found here: \url{https://nwis.waterdata.usgs.gov/nwis/help/?read_file=stat&format=table}
 #'
-#' @param siteNumber string or vector of strings USGS site number.  This is usually an 8 digit number
+#' @param siteNumbers string or vector of strings USGS site number.  This is usually an 8 digit number
 #' @param parameterCd string or vector of USGS parameter code.  This is usually an 5 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 #' retrieval for the earliest possible record.
@@ -26,34 +26,38 @@
 #' provide statistics for each month and year within the range individually.
 #' @param statType character Only used for statistics service requests. Type(s) of statistics to output for daily values.  Default is mean, which is the only
 #' option for monthly and yearly report types. See the statistics service documentation 
-#' at \url{http://waterservices.usgs.gov/rest/Statistics-Service.html#statType} for a full list of codes.
+#' at \url{https://waterservices.usgs.gov/rest/Statistics-Service.html#statType} for a full list of codes.
 #' @keywords data import USGS web service
 #' @return url string
 #' @export
 #' @import utils
 #' @examples
-#' siteNumber <- '01594440'
+#' site_id <- '01594440'
 #' startDate <- '1985-01-01'
 #' endDate <- ''
 #' pCode <- c("00060","00010")
-#' url_daily <- constructNWISURL(siteNumber,pCode,
+#' url_daily <- constructNWISURL(site_id,pCode,
 #'            startDate,endDate,'dv',statCd=c("00003","00001"))
-#' url_unit <- constructNWISURL(siteNumber,pCode,"2012-06-28","2012-06-30",'iv')
+#' url_unit <- constructNWISURL(site_id,pCode,"2012-06-28","2012-06-30",'iv')
 #' 
-#' url_qw_single <- constructNWISURL(siteNumber,"01075",startDate,endDate,'qw')
-#' url_qw <- constructNWISURL(siteNumber,c('01075','00029','00453'),
+#' url_qw_single <- constructNWISURL(site_id,"01075",startDate,endDate,'qw')
+#' url_qw <- constructNWISURL(site_id,c('01075','00029','00453'),
 #'            startDate,endDate,'qw')
-#' url_daily_tsv <- constructNWISURL(siteNumber,pCode,startDate,endDate,'dv',
+#' url_daily_tsv <- constructNWISURL(site_id,pCode,startDate,endDate,'dv',
 #'            statCd=c("00003","00001"),format="tsv")
-#' url_rating <- constructNWISURL(siteNumber,service="rating",ratingType="base")
-#' url_peak <- constructNWISURL(siteNumber, service="peak")
-#' url_meas <- constructNWISURL(siteNumber, service="meas")
+#' url_rating <- constructNWISURL(site_id,service="rating",ratingType="base")
+#' url_peak <- constructNWISURL(site_id, service="peak")
+#' url_meas <- constructNWISURL(site_id, service="meas")
 #' urlQW <- constructNWISURL("450456092225801","70300",startDate="",endDate="","qw",expanded=TRUE)
-constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate="",
+constructNWISURL <- function(siteNumbers,parameterCd="00060",startDate="",endDate="",
                              service,statCd="00003", format="xml",expanded=TRUE,
                              ratingType="base",statReportType="daily",statType="mean"){
 
-  service <- match.arg(service, c("dv","uv","iv","qw","gwlevels","rating","peak","meas","stat"))
+  service <- match.arg(service, c("dv","uv","iv","qw","gwlevels","rating","peak","meas","stat", "qwdata"))
+  
+  service[service == "qw"] <- "qwdata"
+  service[service == "meas"] <- "measurements"
+  service[service == "uv"] <- "iv"
   
   if(any(!is.na(parameterCd) & parameterCd != "all")){
     pcodeCheck <- all(nchar(parameterCd) == 5) & all(!is.na(suppressWarnings(as.numeric(parameterCd))))
@@ -68,41 +72,38 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
     }
   }
   
-  multipleSites <- length(siteNumber) > 1
+  multipleSites <- length(siteNumbers) > 1
   
-  siteNumber <- paste(siteNumber, collapse=",")
+  siteNumbers <- paste(siteNumbers, collapse=",")
+  
+  baseURL <- drURL(service, Access=pkg.env$access)
   
   switch(service,
-         qw = {
+         qwdata = {
              if(multipleSites){    
-               
-               siteNumber <- paste("multiple_site_no",siteNumber,sep="=")
                searchCriteria <- "multiple_site_no"
+               url <- appendDrURL(baseURL,multiple_site_no=siteNumbers)
              } else {
-               siteNumber <- paste("search_site_no",siteNumber,sep="=")
-               siteNumber <- paste(siteNumber,"search_site_no_match_type=exact",sep="&")
                searchCriteria <- "search_site_no"
+               url <- appendDrURL(baseURL,
+                                  search_site_no=siteNumbers,
+                                  search_site_no_match_type="exact")
              }
              
              multiplePcodes <- length(parameterCd)>1
              
              if(multiplePcodes){
                pCodes <- paste(parameterCd, collapse=",")
-               pCodes <- paste('multiple_parameter_cds', pCodes, sep="=")
-               pCodes <- paste(pCodes, "param_cd_operator=OR",sep="&")
+               url <- appendDrURL(url,multiple_parameter_cds=pCodes,param_cd_operator="OR")
              } else {
-               pCodes <- paste("multiple_parameter_cds", parameterCd, sep="=")
-               pCodes <- paste(pCodes, "param_cd_operator=AND",sep="&")
+               url <- appendDrURL(url,multiple_parameter_cds=parameterCd,param_cd_operator="AND")
              }
              
              searchCriteria <- paste(searchCriteria, "multiple_parameter_cds", sep=",")
-             searchCriteria <- paste("list_of_search_criteria",searchCriteria,sep="=")
+             url <- appendDrURL(url, list_of_search_criteria = searchCriteria)
 
-             baseURL <- drURL("qwdata")
              
-             url <- paste0(baseURL,siteNumber)
-             url <- paste(url, pCodes,searchCriteria,
-                          "group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd",
+             url <- paste(url, "group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd",
                           "column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file",
                           "TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0",
                           "format=rdb&rdb_qw_attributes=0&date_format=YYYY-MM-DD",
@@ -124,10 +125,10 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
            },
         rating = {
           ratingType <- match.arg(ratingType, c("base", "corr", "exsa"))
-          url <- drURL("rating", site_no=siteNumber,file_type=ratingType)
+          url <- appendDrURL(baseURL, site_no=siteNumbers,file_type=ratingType)
         },
         peak = {
-          url <- drURL("peak", site_no=siteNumber,
+          url <- appendDrURL(baseURL, site_no=siteNumbers, 
                        range_selection="date_range",
                        format="rdb")
           if (nzchar(startDate)) {
@@ -137,8 +138,8 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
             url <- appendDrURL(url, end_date=endDate)
           }
         },
-        meas = {
-          url <- drURL("measurements", site_no=siteNumber,
+        measurements = {
+          url <- appendDrURL(baseURL, site_no=siteNumbers, 
                        range_selection="date_range")
           if (nzchar(startDate)) {
             url <- appendDrURL(url,begin_date=startDate)
@@ -173,7 +174,7 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
           }
           statType <- paste(statType,collapse=",")
           parameterCd <- paste(parameterCd,collapse=",")
-          url <- drURL("stat", sites=siteNumber,
+          url <- appendDrURL(baseURL, sites=siteNumbers,
                        statType=statType,
                        statReportType=statReportType,
                        parameterCd=parameterCd)
@@ -189,17 +190,13 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
           
         },
         
-        { # this will be either dv or uv
+        { # this will be either dv, uv, groundwater
           multiplePcodes <- length(parameterCd)>1
           # Check for 5 digit parameter code:
           if(multiplePcodes){
             parameterCd <- paste(parameterCd, collapse=",")
           } 
-          
-          if ("uv"==service) {
-            service <- "iv"
-          }
-          
+
           format <- match.arg(format, c("xml","tsv","wml1","wml2","rdb"))
           
           formatURL <- switch(format,
@@ -220,7 +217,7 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
             }
           )
 
-          url <- drURL(service, Access=pkg.env$access, site=siteNumber, format=formatURL)
+          url <- appendDrURL(baseURL, site=siteNumbers, format=formatURL)
           
           if("gwlevels"!= service){
             url <- appendDrURL(url, ParameterCd=parameterCd)
@@ -257,11 +254,9 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
 
 #' Construct WQP url for data retrieval
 #'
-#' Imports data from WQP web service. This function gets the data from here: \url{http://nwis.waterdata.usgs.gov/nwis/qwdata}
-#' A list of parameter codes can be found here: \url{http://nwis.waterdata.usgs.gov/nwis/pmcodes/}
-#' A list of statistic codes can be found here: \url{http://nwis.waterdata.usgs.gov/nwis/help/?read_file=stat&format=table}
+#' Construct WQP url for data retrieval. This function gets the data from here: \url{https://www.waterqualitydata.us}
 #'
-#' @param siteNumber string or vector of strings USGS site number.  This is usually an 8 digit number
+#' @param siteNumbers string or vector of strings USGS site number.  This is usually an 8 digit number
 #' @param parameterCd string or vector of USGS parameter code.  This is usually an 5 digit number.
 #' @param startDate character starting date for data retrieval in the form YYYY-MM-DD. Default is "" which indicates
 #' retrieval for the earliest possible record.
@@ -272,18 +267,18 @@ constructNWISURL <- function(siteNumber,parameterCd="00060",startDate="",endDate
 #' @return url string
 #' @export
 #' @examples
-#' siteNumber <- '01594440'
+#' site_id <- '01594440'
 #' startDate <- '1985-01-01'
 #' endDate <- ''
 #' pCode <- c("00060","00010")
-#' url_wqp <- constructWQPURL(paste("USGS",siteNumber,sep="-"),
+#' url_wqp <- constructWQPURL(paste("USGS",site_id,sep="-"),
 #'            c('01075','00029','00453'),
 #'            startDate,endDate)
-constructWQPURL <- function(siteNumber,parameterCd,startDate,endDate,zip=FALSE){
+constructWQPURL <- function(siteNumbers,parameterCd,startDate,endDate,zip=FALSE){
   
-  multipleSites <- length(siteNumber) > 1
+  multipleSites <- length(siteNumbers) > 1
   multiplePcodes <- length(parameterCd)>1
-  siteNumber <- paste(siteNumber, collapse=";")
+  siteNumbers <- paste(siteNumbers, collapse=";")
 
   if(all(nchar(parameterCd) == 5)){
     suppressWarnings(pCodeLogic <- all(!is.na(as.numeric(parameterCd))))
@@ -296,9 +291,8 @@ constructWQPURL <- function(siteNumber,parameterCd,startDate,endDate,zip=FALSE){
     parameterCd <- paste(parameterCd, collapse=";")
   }
   
-  baseURL <- "http://www.waterqualitydata.us/Result/search?siteid="
+  baseURL <- drURL("wqpData", siteid = siteNumbers, Access=pkg.env$access) 
   url <- paste0(baseURL,
-                siteNumber,
                 ifelse(pCodeLogic,"&pCode=","&characteristicName="),
                 parameterCd)
   
@@ -324,7 +318,7 @@ constructWQPURL <- function(siteNumber,parameterCd,startDate,endDate,zip=FALSE){
 
 #' Construct URL for NWIS water use data service
 #' 
-#' Reconstructs URLs to retrieve data from here: \url{http://waterdata.usgs.gov/nwis/wu}
+#' Reconstructs URLs to retrieve data from here: \url{https://waterdata.usgs.gov/nwis/wu}
 #' 
 #' @param years integer Years for data retrieval. Must be years ending in 0 or 5, or "ALL", which retrieves all available years.
 #' @param stateCd could be character (full name, abbreviation, id), or numeric (id)
@@ -336,21 +330,23 @@ constructWQPURL <- function(siteNumber,parameterCd,startDate,endDate,zip=FALSE){
 #' url <- constructUseURL(years=c(1990,1995),stateCd="Ohio",countyCd = c(1,3), categories = "ALL")
 #' 
 constructUseURL <- function(years,stateCd,countyCd,categories){ 
-    baseURL <- "http://waterdata.usgs.gov/"
-    base2 <- "nwis/water_use?format=rdb&rdb_compression=value"
+
     if(is.null(stateCd)){
-      baseURL <- paste0(baseURL,base2)
-    } else{
+      baseURL <- drURL("useNat", format="rdb", rdb_compression="value", Access=pkg.env$access)
+    } else {
       stateCd <- stateCdLookup(input = stateCd, outputType = "postal")
+      baseURL <- "https://waterdata.usgs.gov/"
+      base2 <- "nwis/water_use?format=rdb&rdb_compression=value"
       baseURL <- paste0(baseURL,paste0(stateCd,"/"),base2)
+      
       if(!is.null(countyCd)){
         
         if(length(countyCd) > 1) {countyCd <- paste(countyCd,collapse="%2C")}
           baseURL <- paste0(baseURL,"&wu_area=county&wu_county=",countyCd)
-      } else{
-          baseURL <- paste0(baseURL,"&wu_area=State%20Total")
-        }
+      } else {
+        baseURL <- paste0(baseURL,"&wu_area=State%20Total")
       }
+    }
     years <- paste(years, collapse="%2C")
     categories <- paste(categories, collapse = "%2C")
     retURL <- paste0(baseURL,"&wu_year=",years,"&wu_category=",categories)
