@@ -1,6 +1,6 @@
 #' USGS data availability
 #'
-#' Imports a table of available parameters, period of record, and count. See \url{http://waterservices.usgs.gov/rest/Site-Service.html}
+#' Imports a table of available parameters, period of record, and count. See \url{https://waterservices.usgs.gov/rest/Site-Service.html}
 #' for more information.
 #'
 #' @param siteNumbers character USGS site number or multiple sites.
@@ -61,8 +61,8 @@
 #' # To find just unit value ('instantaneous') data:
 #' uvData <- whatNWISdata('05114000',service="uv")
 #' uvDataMulti <- whatNWISdata(c('05114000','09423350'),service=c("uv","dv"))
-#' siteNumbers <- c("01491000","01645000")
-#' flowAndTemp <- whatNWISdata(siteNumbers, parameterCd=c("00060","00010"))
+#' site_ids <- c("01491000","01645000")
+#' flowAndTemp <- whatNWISdata(site_ids, parameterCd=c("00060","00010"))
 #' }
 whatNWISdata <- function(siteNumbers,service="all",parameterCd="all",statCd="all"){
   
@@ -73,7 +73,7 @@ whatNWISdata <- function(siteNumbers,service="all",parameterCd="all",statCd="all
   }
   
   if(!("all" %in% parameterCd)){
-    if(any(!is.na(parameterCd))){
+    if(anyNA(parameterCd)){
       pcodeCheck <- all(nchar(parameterCd) == 5) & all(!is.na(suppressWarnings(as.numeric(parameterCd))))
       
       if(!pcodeCheck){
